#![warn(clippy::pedantic)]
#![allow(clippy::unreadable_literal, clippy::double_must_use)]

pub mod analysis;
pub mod games;
pub mod types;
pub mod util;
